==> print-manager_4.14.2.orig.tar.xz: print-manager-4.14.2/libkcups/KCupsServer.h <==
/***************************************************************************
 *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KCUPSSERVER_H
#define KCUPSSERVER_H

#include <QString>
#include <KCupsConnection.h>

class KDE_EXPORT KCupsServer
{
public:
    KCupsServer();

    bool allowRemoteAdmin() const;
    void setAllowRemoteAdmin(bool allow);

    bool allowUserCancelAnyJobs() const;
    void setAllowUserCancelAnyJobs(bool allow);

    bool showSharedPrinters() const;
    void setShowSharedPrinters(bool show);

    bool sharePrinters() const;
    void setSharePrinters(bool share);

    bool allowPrintingFromInternet() const;
    void setAllowPrintingFromInternet(bool allow);

    QVariantHash arguments() const;

protected:
    KCupsServer(const QVariantHash &arguments);

private:
    friend class KCupsRequest;

    QVariantHash m_arguments;
};

Q_DECLARE_METATYPE(KCupsServer)

#endif // KCUPSSERVER_H

==> print-manager-15.08.2.tar.xz: print-manager-15.08.2/libkcups/KCupsServer.h <==
/***************************************************************************
 *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KCUPSSERVER_H
#define KCUPSSERVER_H

#include <QString>
#include <KCupsConnection.h>

class Q_DECL_EXPORT KCupsServer
{
public:
    KCupsServer();

    bool allowRemoteAdmin() const;
    void setAllowRemoteAdmin(bool allow);

    bool allowUserCancelAnyJobs() const;
    void setAllowUserCancelAnyJobs(bool allow);

    bool showSharedPrinters() const;
    void setShowSharedPrinters(bool show);

    bool sharePrinters() const;
    void setSharePrinters(bool share);

    bool allowPrintingFromInternet() const;
    void setAllowPrintingFromInternet(bool allow);

    QVariantHash arguments() const;

protected:
    KCupsServer(const QVariantHash &arguments);

private:
    friend class KCupsRequest;

    QVariantHash m_arguments;
};

Q_DECLARE_METATYPE(KCupsServer)

#endif // KCUPSSERVER_H
